@@ -7,15 +7,17 @@ from typing import Union
 
 import jinja2
 
-from memray import MemoryRecord
+from memray import MemorySnapshot
 from memray import Metadata
 
 
 @lru_cache(maxsize=1)
 def get_render_environment() -> jinja2.Environment:
-    return jinja2.Environment(
+    env = jinja2.Environment(
         loader=jinja2.PackageLoader("memray.reporters"),
     )
+    env.policies["json.dumps_kwargs"] = {"sort_keys": True, "separators": (",", ":")}
+    return env
 
 
 def get_report_title(*, kind: str, show_memory_leaks: bool) -> str:
@@ -29,7 +31,7 @@ def render_report(
     kind: str,
     data: Union[Dict[str, Any], Iterable[Dict[str, Any]]],
     metadata: Metadata,
-    memory_records: Iterable[MemoryRecord],
+    memory_records: Iterable[MemorySnapshot],
     show_memory_leaks: bool,
     merge_threads: bool,
 ) -> str:
